==> marble-4.8.5.tar.xz: marble-4.8.5/src/lib/geodata/parser/GeoDataTypes.cpp <==
/*
    Copyright (C) 2008 Jens-Michael Hoffmann <jensmh@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "GeoDataTypes.h"

namespace Marble
{

namespace GeoDataTypes
{
const char* GeoDataColorStyleType = "GeoDataColorStyle";
const char* GeoDataContainerType = "GeoDataContainer";
const char* GeoDataDataType = "GeoDataData";
const char* GeoDataDocumentType = "GeoDataDocument";
const char* GeoDataExtendedDataType = "GeoDataExtendedData";
const char* GeoDataFeatureType = "GeoDataFeature";
const char* GeoDataFolderType = "GeoDataFolder";
const char* GeoDataGeometryType = "GeoDataGeometry";
const char* GeoDataHotspotType = "GeoDataHotspot";
const char* GeoDataIconStyleType = "GeoDataIconStyle";
const char* GeoDataInnerBoundaryType = "GeoDataInnerBoundary";
const char* GeoDataLabelStyleType = "GeoDataLabelStyle";
const char* GeoDataLatLonAltBoxType = "GeoDataLatLonAlt";
const char* GeoDataLatLonBoxType = "GeoDataLatLonBox";
const char* GeoDataLinearRingType = "GeoDataLinearRing";
const char* GeoDataLineStringType = "GeoDataLineString";
const char* GeoDataLineStyleType = "GeoDataLineStyle";
const char* GeoDataLodType = "GeoDataLod";
const char* GeoDataLookAtType = "GeoDataLoookAt";
const char* GeoDataMultiGeometryType = "GeoDataMultyGeometry";
const char* GeoDataObjectType = "GeoDataObject";
const char* GeoDataOuterBoundaryType = "GeoDataOuterBoundary";
const char* GeoDataPlacemarkType = "GeoDataPlacemark";
const char* GeoDataPointType = "GeoDataPoint";
const char* GeoDataPolygonType = "GeoDataPolygon";
const char* GeoDataPolyStyleType = "GeoDataPolyStyle";
const char* GeoDataRegionType = "GeoDataRegion";
const char* GeoDataStyleSelectorType = "GeoDataStyleSelector";
const char* GeoDataStyleType = "GeoDataStyle";
const char* GeoDataStyleMapType = "GeoDataStyleMap";
const char* GeoDataTimePrimitiveType = "GeoDataTimePrimitive";
const char* GeoDataTimeSpanType = "GeoDataTimeSpan";
const char* GeoDataTimeStampType = "GeoDataTimeStamp";
const char* GeoDataTrackType = "GeoDataTrack";
}

}

==> marble-4.8.80.tar.xz: marble-4.8.80/src/lib/geodata/parser/GeoDataTypes.cpp <==
/*
    Copyright (C) 2008 Jens-Michael Hoffmann <jensmh@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "GeoDataTypes.h"

namespace Marble
{

namespace GeoDataTypes
{
const char* GeoDataColorStyleType = "GeoDataColorStyle";
const char* GeoDataContainerType = "GeoDataContainer";
const char* GeoDataDataType = "GeoDataData";
const char* GeoDataDocumentType = "GeoDataDocument";
const char* GeoDataExtendedDataType = "GeoDataExtendedData";
const char* GeoDataFeatureType = "GeoDataFeature";
const char* GeoDataFolderType = "GeoDataFolder";
const char* GeoDataGeometryType = "GeoDataGeometry";
const char* GeoDataGroundOverlayType = "GeoDataGroundOverlay";
const char* GeoDataHotspotType = "GeoDataHotspot";
const char* GeoDataIconStyleType = "GeoDataIconStyle";
const char* GeoDataInnerBoundaryType = "GeoDataInnerBoundary";
const char* GeoDataLabelStyleType = "GeoDataLabelStyle";
const char* GeoDataLatLonAltBoxType = "GeoDataLatLonAlt";
const char* GeoDataLatLonBoxType = "GeoDataLatLonBox";
const char* GeoDataLinearRingType = "GeoDataLinearRing";
const char* GeoDataLineStringType = "GeoDataLineString";
const char* GeoDataLineStyleType = "GeoDataLineStyle";
const char* GeoDataLodType = "GeoDataLod";
const char* GeoDataLookAtType = "GeoDataLoookAt";
const char* GeoDataMultiGeometryType = "GeoDataMultyGeometry";
const char* GeoDataObjectType = "GeoDataObject";
const char* GeoDataOuterBoundaryType = "GeoDataOuterBoundary";
const char* GeoDataPhotoOverlayType = "GeoDataPhotoOverlay";
const char* GeoDataPlacemarkType = "GeoDataPlacemark";
const char* GeoDataPointType = "GeoDataPoint";
const char* GeoDataPolygonType = "GeoDataPolygon";
const char* GeoDataPolyStyleType = "GeoDataPolyStyle";
const char* GeoDataRegionType = "GeoDataRegion";
const char* GeoDataSimpleArrayDataType = "GeoDataSimpleArrayData";
const char* GeoDataStyleSelectorType = "GeoDataStyleSelector";
const char* GeoDataStyleType = "GeoDataStyle";
const char* GeoDataStyleMapType = "GeoDataStyleMap";
const char* GeoDataTimePrimitiveType = "GeoDataTimePrimitive";
const char* GeoDataTimeSpanType = "GeoDataTimeSpan";
const char* GeoDataTimeStampType = "GeoDataTimeStamp";
const char* GeoDataTrackType = "GeoDataTrack";
}

}
